@@ -12,7 +12,7 @@ if(isprint("abc\000abc") || isprint("abc\001abc") || !isprint("barra"))
 
 
 use strict;
-our $VERSION = '2.2.3';
+our $VERSION = '2.1';
 use CGI qw(escapeHTML);
 use CGI::Cookie;
 require Exporter;
@@ -34,9 +34,6 @@ our %defaults = (
 
 our $have_gd_graph = eval { require GD::Graph::lines; };
 
-our $redo_screen_js =
-  "this.form.redo_screen.value=1; this.form.submit();";
-
 sub new {
     my $type = shift;
     my ($class) = ref($type) || $type;
@@ -52,47 +49,40 @@ sub new {
 			['forced','0'],
 			['single','size'],
 			['single','maxsize'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     $self->add_handler('hidetext',\&QWizard::Generator::HTML::do_entry,
 		       [['single','name'],
 			['default'],
 			['forced','1'],
 			['single','size'],
 			['single','maxsize'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     $self->add_handler('textbox',\&QWizard::Generator::HTML::do_textbox,
 		       [['default'],
 			['single', 'width'],
 			['single', 'size'],
 			['single', 'height'],
-			['single', 'submit'],
-			['single','refresh_on_change']]);
+			['single', 'submit']]);
     $self->add_handler('checkbox',\&QWizard::Generator::HTML::do_checkbox,
 		       [['multi','values'],
 			['default'],
-			['single', 'submit'],
-			['single','refresh_on_change']]);
+			['single', 'submit']]);
     $self->add_handler('multi_checkbox',
 		       \&QWizard::Generator::HTML::do_multicheckbox,
 		       [['multi','default'],
 			['values,labels'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     $self->add_handler('menu',
 		       \&QWizard::Generator::HTML::do_menu,
 		       [['values,labels', "   "],
 			['default'],
 			['single','submit'],
-			['single','refresh_on_change'],
 			['single', 'name']]);
     $self->add_handler('radio',
 		       \&QWizard::Generator::HTML::do_radio,
 		       [['values,labels'],
 			['default'],
 			['single','submit'],
-			['single','refresh_on_change'],
 			['single','name']]);
     $self->add_handler('label',
 		       \&QWizard::Generator::HTML::do_label,
@@ -112,9 +102,6 @@ sub new {
 		       \&QWizard::Generator::HTML::do_table,
 		       [['norecurse','values'],
 			['norecurse','headers']]);
-    $self->add_handler('bar',
-		       \&QWizard::Generator::HTML::do_bar,
-		       [['norecurse','values']]);
     $self->add_handler('graph',
 		       \&QWizard::Generator::HTML::do_graph,
 		       [['norecurse','values'],
@@ -181,9 +168,8 @@ sub init_screen {
 sub wait_for {
   my ($self, $wiz, $next, $p) = @_;
   print "<P><input type=submit value=\"" . escapeHTML($next) . "\">\n";
-  $self->do_hidden($wiz, "redo_screen", 0) if (!$self->qwparam('redo_screen'));
   if ($self->qwparam('allow_refresh') || $p->{'allow_refresh'}) {
-      print "<input type=submit onclick=\"$redo_screen_js\" name=redo_screen_but value=\"Refresh Screen\">\n";
+      print "<input type=submit name=redo_screen value=\"Refresh Screen\">\n";
   }
   print $self->{'cgi'}->end_form();
   return 1;
@@ -212,15 +198,7 @@ sub do_question {
 	print escapeHTML($text);
     }
     if ($q->{'helpdesc'}) {
-
-      #
-      # Get the actual help text, in case this is a subroutine.
-      #
-      my $helptext = $q->{'helpdesc'};
-      if (ref($helptext) eq "CODE") {
-          $helptext = $helptext->();
-      }
-      print "<br><small><i>" . escapeHTML($helptext) . "</i></small>";
+      print "<br><small><i>" . escapeHTML($q->{helpdesc}) . "</i></small>";
     }
     print "</td><td" . $self->do_css('qwquestion',$q->{'name'}, 1) . ">\n";
 }
@@ -246,7 +224,6 @@ sub start_questions {
 	print "<p class=\"qwintroduction\">$intro\n<p class=\"qwintroduction\">\n";
     }
     print "<table class=\"qwquestions\">\n";
-    $self->{'intable'} = 1;
 }
 
 sub end_questions {
@@ -262,7 +239,6 @@ sub end_questions {
     print "</script>\n";
 
     $self->{'started'} = $wiz->{'started'} = 0;
-    delete($self->{'intable'});
 }
 
 sub do_pass {
@@ -271,40 +247,6 @@ sub do_pass {
       if ($self->qwparam($name) ne '');
 }
 
-##################################################
-# Bar support
-##################################################
-
-sub start_bar {
-    my ($self, $wiz, $name) = @_;
-    if ($self->{'intable'}) {
-	print "</table>\n";
-    }
-    print "<div " . $self->do_css('qwbar',$name) . ">\n";
-}
-
-sub end_bar {
-    my ($self, $wiz, $name) = @_;
-    print "</div>\n";
-    if ($self->{'intable'}) {
-	print "<table class=\"qwquestions\">\n";
-    }
-}
-
-sub do_bar {
-    my ($self, $q, $wiz, $p, $widgets) = @_;
-
-    $self->start_bar($wiz, undef);
-    $self->do_a_table([$widgets], 0, $wiz, $q, $p);
-    $self->end_bar($wiz, 'Questions');
-}
-
-sub do_top_bar {
-    my ($self, $q, $wiz, $p, $widgets) = @_;
-
-    $self->do_a_table([$widgets], 0, $wiz, $q, $p);
-}
-
 ##################################################
 # widgets
 ##################################################
@@ -315,7 +257,7 @@ sub do_button {
 }
 
 sub do_checkbox {
-    my ($self, $q, $wiz, $p, $vals, $def, $submit, $refresh_on_change) = @_;
+    my ($self, $q, $wiz, $p, $vals, $def, $submit) = @_;
     $vals = [1, 0] if ($#$vals == -1);
     my $otherstuff;
     if ($def == $vals->[0]) {
@@ -327,18 +269,13 @@ sub do_checkbox {
     if ($submit) {
 	$otherstuff .= " onclick=\"this.form.submit()\"";
     }
-    if ($refresh_on_change) {
-	$otherstuff .= " onclick=\"$redo_screen_js\"";
-    }
     print "<input" . $self->do_css('qwcheckbox',$q->{'name'}) . " type=checkbox name=\"$q->{name}\"$otherstuff>";
 }
 
 sub do_multicheckbox {
-    my ($self, $q, $wiz, $p, $defs, $vals, $labels,
-	$submit, $refresh_on_change) = @_;
+    my ($self, $q, $wiz, $p, $defs, $vals, $labels, $submit) = @_;
     print "<table>";
     my $count = -1;
-    my ($startname, $endname);
     foreach my $v (@$vals) {
 	$count++;
 	my $otherstuff;
@@ -346,111 +283,29 @@ sub do_multicheckbox {
 	if ($submit) {
 	    $otherstuff .= " onclick=\"this.form.submit()";
 	}
-	if ($refresh_on_change) {
-	    $otherstuff .= " onclick=\"$redo_screen_js\"";
-	}
 	my $l = (($labels->{$v}) ? $labels->{$v} : "$v");
 	print "<tr><td>" . escapeHTML($l)  . "</td>\n";
 	print "<td><input" . $self->do_css('qwmulticheckbox',$q->{'name'}) . " $otherstuff value=\"" . escapeHTML($v) . 
 	  "\" type=checkbox name=\"$q->{name}$l\"></td></tr>";
 	# XXX: hack:
 	push @{$wiz->{'passvars'}},$q->{'name'} . $v;
-	$startname = "$q->{name}$l" if ($count == 0);
-	$endname = "$q->{name}$l" if ($count == $#$vals);
     }
-
     print "</table>";
-
-    #Javascript for setting/unsetting/toggling buttons
-    print "
-
-<script language=\"JavaScript\">
-    function $q->{name}_setall() {
-      var doit = false;
-      for (i=0; i<document.qwform.elements.length; i++) {
-        if (document.qwform.elements[i].type == \"checkbox\") {
-          if (document.qwform.elements[i].name == \"$startname\") {
-            doit = true;
-          }
-          if (doit) {
-            document.qwform.elements[i].checked = true;
-          }
-          if (document.qwform.elements[i].name == \"$endname\") {
-            doit = false;
-          }
-        }
-      }
-    }
-
-    function $q->{name}_unsetall() {
-      var doit = false;
-      for (i=0; i<document.qwform.elements.length; i++) {
-        if (document.qwform.elements[i].type == \"checkbox\") {
-          if (document.qwform.elements[i].name == \"$startname\") {
-            doit = true;
-          }
-          if (doit) {
-            document.qwform.elements[i].checked = false;
-          }
-          if (document.qwform.elements[i].name == \"$endname\") {
-            doit = false;
-          }
-        }
-      }
-    }
-
-    function $q->{name}_toggleall() {
-      var doit = false;
-      for (i=0; i<document.qwform.elements.length; i++) {
-        if (document.qwform.elements[i].type == \"checkbox\") {
-          if (document.qwform.elements[i].name == \"$startname\") {
-            doit = true;
-          }
-          if (doit) {
-            if (document.qwform.elements[i].checked) {
-              document.qwform.elements[i].checked = false;
-            } else {
-              document.qwform.elements[i].checked = true;
-            }
-          }
-          if (document.qwform.elements[i].name == \"$endname\") {
-            doit = false;
-          }
-        }
-      }
-    }
-	    ";
-#     foreach my $boxname (@boxnames) {
-# 	print " document.qwform.try1.checked=true;\n";
-# #	print " document.qwform.\"$boxname\".checked=true;\n";
-#     }
-    print "
-</script>
-
-<a href=\"javascript:$q->{name}_setall()\">[Set All]</a>
-<a href=\"javascript:$q->{name}_unsetall()\">[Unset All]</a>
-<a href=\"javascript:$q->{name}_toggleall()\">[Toggle All]</a>
-
-";
-
 }
 
 sub do_radio {
-    my ($self, $q, $wiz, $p, $vals, $labels, $def,
-	$submit, $refresh_on_change, $name) = @_;
+    my ($self, $q, $wiz, $p, $vals, $labels, $def, $submit, $name) = @_;
     my @stuff;
     push @stuff, -onclick, "this.form.submit()" if ($submit);
-    push @stuff, -onclick, "$redo_screen_js" if ($refresh_on_change);
 
     print $self->{'cgi'}->radio_group(-name => $name,
-				      -id => "qwradio$name",
+				      -id => 'qwradio$name',
 				      -class => 'qwradio',
 				      -values => $vals,
 				      -linebreak => 'true',
 				      -labels => $labels,
-				      -override => 1,
 				      -default => $def,
-				      @stuff),"\n";
+				      @stuff);
 }
 
 
@@ -485,17 +340,14 @@ sub do_paragraph {
 }
 
 sub do_menu {
-    my ($self, $q, $wiz, $p, $vals, $labels, $def,
-	$submit, $refresh_on_change, $name) = @_;
+    my ($self, $q, $wiz, $p, $vals, $labels, $def, $submit, $name) = @_;
     my @stuff;
     push @stuff, -onchange, "this.form.submit()" if ($submit);
-    push @stuff, -onchange, "$redo_screen_js" if ($refresh_on_change);
 
     print $self->{'cgi'}->popup_menu(-name => $name,
 				     -id => 'qwmenu' . $name,
 				     -class => 'qwmenu',
 				     -values => $vals,
-				     -override => 1,
 				     -labels => $labels,
 				     -default => $def,
 				     @stuff);
@@ -506,9 +358,8 @@ sub do_fileupload {
 
     push @{$wiz->{'passvars'}}, $q->{'name'} . "_qwf";
     print $self->{'cgi'}->filefield(-name => $q->{name},
-				    -id => 'qwmenu' . $q->{'name'},
-				    -class => 'qwmenu',
-				    -override => 1,
+				     -id => 'qwmenu' . $q->{'name'},
+				     -class => 'qwmenu',
 				    -default => $def);
 }
 
@@ -589,8 +440,7 @@ sub qw_upload_fh {
 }
 
 sub do_entry {
-    my ($self, $q, $wiz, $p, $name, $def, $hide, $size, $maxsize,
-	$submit, $refresh_on_change) = @_;
+    my ($self, $q, $wiz, $p, $name, $def, $hide, $size, $maxsize, $submit) = @_;
     my $otherinfo;
     if ($size) {
 	$otherinfo .= " size=\"$size\"";
@@ -608,9 +458,6 @@ sub do_entry {
     if ($submit) {
 	$otherinfo .= " onchange=\"this.form.submit()\"";
     }
-    if ($refresh_on_change) {
-	$otherinfo .= " onclick=\"$redo_screen_js\"";
-    }
 
     #
     # If the hide flag was set, we'll treat this as unprintable text.
@@ -624,7 +471,7 @@ sub do_entry {
 }
 
 sub do_textbox {
-    my ($self, $q, $wiz, $p, $def, $width, $size, $height, $submit, $refresh_on_change) = @_;
+    my ($self, $q, $wiz, $p, $def, $width, $size, $height, $submit) = @_;
     my $otherinfo;
     if ($size || $width) {
 	$size = $size || $width;
@@ -636,18 +483,14 @@ sub do_textbox {
     if ($submit) {
 	$otherinfo .= " onchange=\"this.form.submit()\"";
     }
-    if ($refresh_on_change) {
-	$otherinfo .= " onclick=\"$redo_screen_js\"";
-    }
     print "<textarea" . $self->do_css('qwtextbox',$q->{'name'}) . 
       " name=\"$q->{name}\" $otherinfo>" . escapeHTML($def) . "</textarea>";
 }
 
 sub do_error {
     my ($self, $q, $wiz, $p, $err) = @_;
-    my $name = ($q ? $q->{'name'} : '');
-    print "<tr" . $self->do_css('qwerrorrow',$name) . "><td" .
-      $self->do_css('qwerrorcol',$name) .
+    print "<tr" . $self->do_css('qwerrorrow',$q->{'name'}) . "><td" .
+      $self->do_css('qwerrorcol',$q->{'name'}) .
 	" colspan=3><font color=red>" . escapeHTML($err) .
 	  "</font></td></tr>\n";
 }
@@ -838,12 +681,7 @@ sub do_tree {
 
     my $expanded = $self->qwparam("${treename}_expanded") || $q->{'root'};
     my @expand = split(/,/, $expanded);
-    # redo_screen values:
-    #  1: selects a label
-    #  2: expands a branch
-    #  3: collapses a branch
-    my $redo = $self->qwparam("redoing_now");
-
+    my $redo = $self->qwparam("redo_screen");
     if ($redo == 2 && $self->qwparam("${treename}_collapse")) {
 	push @expand, $self->qwparam("${treename}_collapse");
     } elsif ($redo == 3 && $self->qwparam("${treename}_collapse")) {
@@ -878,6 +716,8 @@ sub do_tree {
     $self->do_hidden($wiz, "${treename}_expanded", $expanded);
     if ($self->{'first_tree'}) { #only one hidden value for redo_screen
 	$self->{'first_tree'} = 0;
+	$self->do_hidden($wiz, "redo_screen", '0');
+	$self->qwparam("redo_screen", $redo); #save the value of tree_redo
     }
     $self->do_hidden($wiz, $treename, $selected);
 
@@ -899,9 +739,7 @@ sub do_tree {
 </script>
 EOF
 
-    print "<div " . $self->do_css('qwtree',$treename) . ">\n";
     print_branch($wiz, $q, $q->{'root'}, $selected, 0, $labels, @expand);
-    print "</div>\n";
 }
 
 sub get_name {
