@@ -1,7 +1,7 @@
 package QWizard::Generator::Tk;
 
 use strict;
-my $VERSION = '2.2.3';
+my $VERSION = '2.1';
 use Tk;
 use Tk::Table;
 use Tk::Pane;
@@ -26,8 +26,7 @@ sub new {
 			['forced','0'],
 			['single','size'],
 			['single','maxsize'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     # XXX: we need to do a real text box
     $self->add_handler('textbox',\&QWizard::Generator::Tk::do_entry,
 		       [['single','name'],
@@ -35,21 +34,18 @@ sub new {
 			['forced','0'],
 			['single','size'],
 			['single','maxsize'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     $self->add_handler('hidetext',\&QWizard::Generator::Tk::do_entry,
 		       [['single','name'],
 			['default'],
 			['forced','1'],
 			['single','size'],
 			['single','maxsize'],
-			['single','submit'],
-			['single','refresh_on_change']]);
+			['single','submit']]);
     $self->add_handler('checkbox',\&QWizard::Generator::Tk::do_checkbox,
 		       [['multi','values'],
 			['default'],
-			['single', 'submit'],
-			['single','refresh_on_change']]);
+			['single', 'submit']]);
     $self->add_handler('multi_checkbox',
 		       \&QWizard::Generator::Tk::do_multicheckbox,
 		       [['multi','default'],
@@ -110,19 +106,12 @@ sub goto_top {
 
 sub goto_next {
     shift if (ref($_[0]) ne 'QWizard::Generator::Tk');
-    my ($self, $ignorefirst_or_varname, $refresh_on_change, $val) = @_;
-    if ($ignorefirst_or_varname &&
-	ref($ignorefirst_or_varname) eq 'SCALAR' && $$ignorefirst_or_varname) {
-	$$ignorefirst_or_varname--;
+    my ($self, $ignorefirst, $val) = @_;
+    if ($ignorefirst && ref($ignorefirst) eq 'SCALAR' && $$ignorefirst) {
+	$$ignorefirst--;
 	return;
-    } elsif (ref($ignorefirst_or_varname) ne 'SCALAR') {
-	if ($ignorefirst_or_varname) {
-	    $self->qwparam($ignorefirst_or_varname, $val);
-	}
-    }
-    if ($refresh_on_change) {
-	print STDERR "redo:!!!\n";
-	$self->qwparam('redo_screen',1);
+    } elsif ($ignorefirst && ref($ignorefirst) ne 'SCALAR') {
+	$self->qwparam($ignorefirst, $val);
     }
 
     $self->unmake_top();
@@ -216,16 +205,14 @@ sub do_ok_cancel {
 					     -borderwidth => 3);
       if (!$self->{'prevbut'}) {
 	  $self->{'prevbut'} = 
-	    $self->{'bot'}->Button(-text => ($wiz->{'back_text'} || 
-						 'Back'),
+	    $self->{'bot'}->Button(-text => ('Back'),
 				   -command => [\&goto_prev, 
 						$self]);
 	  $self->{'prevbut'}->pack(-side => 'left');
       }
       if (!$self->{'nextbut'}) {
 	  $self->{'nextbut'} = 
-	    $self->{'bot'}->Button(-text => ($nexttext  ||
-					     $wiz->{'next_text'} || 'Next'),
+	    $self->{'bot'}->Button(-text => ($nexttext || 'Ok'),
 				   -command => [\&goto_next, 
 						$self]);
 	  $self->{'nextbut'}->pack(-side => 'left');
@@ -233,8 +220,7 @@ sub do_ok_cancel {
       if (! $dontdocan) {
 	  if (!$self->{'canbut'}) {
 	      $self->{'canbut'} = 
-		$self->{'bot'}->Button(-text => ($wiz->{'cancel_text'} || 
-						 'Cancel'),
+		$self->{'bot'}->Button(-text => 'Cancel',
 				       -command => [\&goto_top, $self, $wiz]);
 	      $self->{'canbut'}->pack(-side => 'right');
 	  }
@@ -320,29 +306,19 @@ sub do_error {
 sub do_question {
     my ($self, $q, $wiz, $p, $text, $qcount) = @_;
     my $top = $self->{'qtable'};
-
     $self->{'currentq'} = $qcount + $self->{'qadd'};
-
-    #
-    # Get the actual help text, in case this is a subroutine.
-    #
-    my $helptext = $q->{'helpdesc'};
-    if (ref($helptext) eq "CODE") {
-	$helptext = $helptext->();
-    }
-
-    if ($helptext && !$self->qwpref('usehelpballons')) {
+    if ($q->{'helpdesc'} && !$self->qwpref('usehelpballons')) {
 	my $f = $top->Frame();
 	$f->Label(-text => $text, -anchor => 'nw')->pack(-anchor => 'w');
-	$f->Label(-text => $helptext, -anchor => 'nw',
+	$f->Label(-text => $q->{'helpdesc'}, -anchor => 'nw',
 		  -font => 'Helvetica 12 italic')
 	  ->pack(-anchor => 'w');
 	$self->put_it($f, undef, 1);
     } else {
 	my $l = $top->Label(-text => $text, -anchor => 'nw');
 	$self->put_it($l, undef, 1);
-	if ($self->{'balloon'} && $helptext) {
-	    $self->{'balloon'}->attach($l, -balloonmsg => $helptext);
+	if ($self->{'balloon'} && $q->{'helpdesc'}) {
+	    $self->{'balloon'}->attach($l, -balloonmsg => $q->{'helpdesc'});
 	    # XXX: change the "help" window text, which doesn't exist yet.
 	}
     }
@@ -380,8 +356,7 @@ sub get_extra_args {
 
     my @args;
 
-    if (($q->{'submit'} || $q->{'refresh_on_change'}) &&
-      $q->{type} ne 'text') {
+    if ($q->{'submit'} && $q->{type} ne 'text') {
 	my $ignorefirst = 0;
 	if ($q->{'type'} eq 'menu') {
 	    # menus do an initial call immediately after being created.
@@ -389,8 +364,7 @@ sub get_extra_args {
 	    # (did I mention "sigh"?)
 	    $ignorefirst = 1;
 	}
-	push @args, '-command', [\&goto_next, $self, \$ignorefirst,
-				 $q->{'refresh_on_change'}];
+	push @args, '-command', [\&goto_next, $self, \$ignorefirst];
     }
     return \@args;
 }
@@ -412,7 +386,6 @@ sub do_button {
     my $but = $self->{'qtable'}->Button(-text => $vals,
 					-command => [\&goto_next, 
 						     $self, $q->{'name'},
-						     $q->{'refresh_on_change'},
 						     $def]);
     $self->put_it($but);
 }
