@@ -1,10 +1,8 @@
 package QWizard::Storage::CGIParam;
 
 use strict;
-use QWizard::Storage::Base;
-our @ISA = qw(QWizard::Storage::Base);
 
-our $VERSION = '2.2.3';
+our $VERSION = '2.1';
 use CGI;
 
 our %cached_params = ();
@@ -14,33 +12,37 @@ sub new {
     bless {}, $class;
 }
 
-sub maybe_create_cgi {
-    my $self = shift;
+sub access {
+    my ($self) = shift;
+    my ($it);
+    my $ret;
+    if (ref($self) =~ /QWizard/) {
+	$it = shift;
+    } else {
+	$it = $self;
+    }
     if (!exists($self->{'cgi'})) {
 	# we do this here late binding as possible for various reasons
 	$self->{'cgi'} = new CGI;
     }
+    if ($#_ > -1) {
+	return $cached_params{$it} if (exists($cached_params{$it}));
+	$ret = $self->{'cgi'}->param($it, $_[0]);
+    } else {
+	return $cached_params{$it} if (exists($cached_params{$it}));
+
+	$ret = $self->{'cgi'}->param($it);
+    }
+    #    print STDERR "qwparam (\"$self\", \"$it\", \"$_[0]\") -> $ret\n";
+    return $ret;
 }
 
 sub get {
-    my ($self, $it) = @_;
-    $self->maybe_create_cgi();
-    return $cached_params{$it} if (exists($cached_params{$it}));
-    return $self->{'cgi'}->param($it);
+    return access(@_);
 }
 
 sub set {
-    my ($self, $it, $val) = @_;
-    $self->maybe_create_cgi();
-    return $self->{'cgi'}->param($it, $val);
-}
-
-sub get_all {
-    my ($self) = @_;
-    my %ret;
-    my @names = $self->{'cgi'}->param;
-    map { $ret{$_} = $self->{'cgi'}->param($_) } @names;
-    return \%ret;
+    return access(@_);
 }
 
 sub reset {
