@@ -1,37 +1,47 @@
 package QWizard::Storage::Memory;
 
 use strict;
-use QWizard::Storage::Base;
 
-our @ISA = qw(QWizard::Storage::Base);
-
-our $VERSION = '2.2.3';
+our $VERSION = '2.1';
+use CGI;
 
 sub new {
     my $class = shift;
     bless {}, $class;
 }
 
+sub access {
+    my $self = shift;
+    my ($it);
+    if (ref($self) =~ /QWizard/) {
+	$it = shift;
+    } else {
+	$it = $self;
+    }
+    if ($#_ > -1) {
+	$self->{'vars'}{$it} = $_[0];
+
+    }
+#    print "************************************************** $self $it $self->{'vars'}{$it}\n";
+    return $self->{'vars'}{$it};
+}
+
+sub get {
+    return access(@_);
+}
+
 sub get_all {
     my $self = shift;
     return $self->{'vars'};
 }
 
-sub set {
-    my ($self, $it, $value) = @_;
-    $self->{'vars'}{$it} = $value;
-    return $value;
-}
-
-# faster than the parent iterative method
 sub set_all {
     my $self = shift;
     %{$self->{'vars'}} = %{$_[0]};
 }
 
-sub get {
-    my ($self, $it, $value) = @_;
-    return $self->{'vars'}{$it};
+sub set {
+    return access(@_);
 }
 
 sub reset {
